#ifndef CORSIX_TH_LUA_RNC
#define CORSIX_TH_LUA_RNC

#include "lua.hpp"

int luaopen_rnc(lua_State* L);

#endif
